pub enum CalleeRef {
Direct(FunctionId),
Indirect(AccessPath),
}Expand description
Reference to a callee from within a function body.
Variants
Direct(FunctionId)
Direct call to a known function.
Indirect(AccessPath)
Indirect call through a function pointer at an access path.