pub fn abi_alignment_with_ptr(
ty: &AirType,
types: &BTreeMap<TypeId, AirType>,
ptr_width: u32,
) -> Option<u64>Expand description
Returns the ABI alignment in bytes for a type, using the specified pointer width.
ptr_width is the pointer size in bytes (4 for 32-bit, 8 for 64-bit).
Returns None for Opaque types or types that reference unknown TypeIds.